summary refs log tree commit diff stats
path: root/examples/cross_calculator/ios/src
diff options
context:
space:
mode:
authorFlaviu Tamas <tamasflaviu@gmail.com>2015-01-09 22:59:16 -0500
committerFlaviu Tamas <tamasflaviu@gmail.com>2015-01-09 22:59:16 -0500
commit8b807adc08530c72122a97eea3c96b7b2f13d579 (patch)
tree21a67f2c3a485abea4907f4f96a76a2451c7408d /examples/cross_calculator/ios/src
parentf2e717da2d44a184bc8ce7056391d975cb641e81 (diff)
downloadNim-8b807adc08530c72122a97eea3c96b7b2f13d579.tar.gz
s/nimrod/nim/g; s/babel/nimble/g
Diffstat (limited to 'examples/cross_calculator/ios/src')
-rw-r--r--examples/cross_calculator/ios/src/NRViewController.m6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/cross_calculator/ios/src/NRViewController.m b/examples/cross_calculator/ios/src/NRViewController.m
index bd0df7d6b..1f92f2d38 100644
--- a/examples/cross_calculator/ios/src/NRViewController.m
+++ b/examples/cross_calculator/ios/src/NRViewController.m
@@ -40,7 +40,7 @@
 	// Dismiss all keyboards.
 	[self backgroundTouched];
 
 	// Call nimrod code, store the result and display it.
 	const int a = [self.aText.text intValue];
 	const int b = [self.bText.text intValue];
 	const int c = myAdd(a, b);
@@ -66,7 +66,7 @@
  * was used on the xib file and slightly modified to fit the original property
  * names. Which means here is a lot of garbage you would never write in real
  * life. Please ignore the following "wall of code" for the purposes of
  * learning Nimrod, this is all just because Apple can't be bothered to
  * maintain backwards compatibility properly.
  */
 - (void)loadView
@@ -102,7 +102,7 @@
 	label4.contentStretch = CGRectFromString(@"{{0, 0}, {1, 1}}");
 	label4.frame = CGRectMake(0.0, 0.0, 320.0, 34.0);
 	label4.tag = 2;
-	label4.text = @"Nimrod Crossplatform Calculator";
+	label4.text = @"Nim Crossplatform Calculator";
 	label4.textAlignment = UITextAlignmentCenter;
 
 	UIButton *background_button = [UIButton buttonWithType:UIButtonTypeCustom];
@@ -40,7 +40,7 @@
 	[self backgroundTouched];
 
-	// Call nimrod code, store the result and display it.
+	// Call Nim code, store the result and display it.
 	const int a = [self.aText.text intValue];
 	const int b = [self.bText.text intValue];
@@ -66,7 +66,7 @@
  * names. Which means here is a lot of garbage you would never write in real
  * life. Please ignore the following "wall of code" for the purposes of
- * learning Nimrod, this is all just because Apple can't be bothered to
+ * learning Nim, this is all just because Apple can't be bothered to
  * maintain backwards compatibility properly.
  */